//Change this to about 5-10 degrees cooler than house temperature
int temperature_wanted = 60;

#include <math.h>

#define ThermistorPIN  0                // Analog Pin 0
#define ThermistorPIN2 1                // Analog Pin 1
#define ThermistorPIN3 2                // Analog Pin 2
#define ThermistorPIN4 3                // Analog Pin 3

float pad = 9850;                       // balance/pad resistor value, set this to the measured resistance of your pad resistor
                                        
float thermr = 10000;                   // thermistor nominal resistance

float Thermistor(int RawADC) {
  long Resistance;  
  float Temp;                           // Dual-Purpose variable to save space.

  Resistance=pad*((1024.0 / RawADC) - 1); 
  Temp = log(Resistance);               // Saving the Log(resistance) so not to calculate  it 4 times later
  Temp = 1 / (0.001129148 + (0.000234125 * Temp) + (0.0000000876741 * Temp * Temp * Temp));
  Temp = Temp - 273.15;                 // Convert Kelvin to Celsius                      

  return Temp;                          // Return the Temperature
}

//these floats hold the data while we are getting other data from different thermistors
float temp_one;
float temp_two;
float temp_three;
float temp_four;

//floats used to find the average
float current_average;
float overall_average;

//used to track the time
long current_time;

//used to show if above or below temperature wanted
int green_led = 11;
int red_led   = 10;

void setup() {
  //set up serial monitor
  Serial.begin(115200);
  
  //set leds as outputs
  pinMode(green_led,OUTPUT);
  pinMode(red_led,OUTPUT);
}

void loop() {
  //float for holding the temperature
  float temp;
  
  //find the current time
  current_time = millis();
  
  //print the current time in milliseconds
  Serial.println(current_time);
  
  //find out when 5 mins is up
  if (current_time > 300000) {
    //print to display
    Serial.println("STOP!");
    
    //see if pass the qualifications of how cold
    if (overall_average > temperature_wanted) {
      
      digitalWrite(green_led,HIGH);
      
    } else {
      
      digitalWrite(red_led,HIGH);
      
    }
  } else {
  
    //first thermistor
    temp=Thermistor(analogRead(ThermistorPIN));       // read ADC and  convert it to Celsius
    temp = (temp * 9.0)/ 5.0 + 32.0;                  // converts to  Fahrenheit

    Serial.print("Fahrenheit #1: "); 
    Serial.print(temp,1);                             // display  Fahrenheit
    Serial.println(""); 
    temp_one = temp;
  
    //second thermistor
    temp=Thermistor(analogRead(ThermistorPIN2));       
    temp = (temp * 9.0)/ 5.0 + 32.0;                
  
    Serial.print("Fahrenheit #2: "); 
    Serial.print(temp,1);   
    Serial.println(""); 
    temp_two = temp;
  
    //third thermistor
    temp=Thermistor(analogRead(ThermistorPIN2));      
    temp = (temp * 9.0)/ 5.0 + 32.0;                  
  
    Serial.print("Fahrenheit #3: "); 
    Serial.print(temp,1);  
    Serial.println(""); 
    temp_three = temp;
  
    //fourth thermistor
    temp=Thermistor(analogRead(ThermistorPIN2));   
    temp = (temp * 9.0)/ 5.0 + 32.0;                
  
    Serial.print("Fahrenheit #4: "); 
    Serial.print(temp,1);   
    Serial.println(""); 
    temp_four = temp;
  
    //Average Finder/Printer of those four
    current_average = (temp_one + temp_two + temp_three + temp_four) / 4;
    Serial.print("Current Average: ");
    Serial.print(current_average);
    Serial.println("");
  
    //Overall Average Finder/Printer
    if (overall_average <= 0) {
      overall_average = current_average;
      Serial.print("Overall Average: ");
      Serial.print(overall_average);
      Serial.println("");
     } else {
      overall_average = (current_average + overall_average) / 2;
      Serial.print("Overall Average: ");
      Serial.print(overall_average);
      Serial.println("");
  }
  
  //for organinzing in serial monitor
  Serial.print("-----------------------------------------------");
  Serial.println("");
  
  delay(5000);                                      // Delay a bit... 
  
  }
    
}
